@@ -1,5 +1,4 @@
 /*
- *
  *  This file is part of the XForms library package.
  *
  * XForms is free software; you can redistribute it and/or modify it
@@ -12,26 +11,21 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with XForms; see the file COPYING.  If not, write to
- * the Free Software Foundation, 59 Temple Place - Suite 330, Boston,
- * MA 02111-1307, USA.
- *
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with XForms. If not, see <http://www.gnu.org/licenses/>.
  */
 
 
 /**
  * \file extern.h
  *
- *.
  *  This file is part of the XForms library package.
  *  Copyright (c) 1996-1998  T.C. Zhao and Mark Overmars
  *  All rights reserved.
- *.
+ *
  * All global variables used in forms.  Should not be used
  * by application programs.  There is no guarantee that these
  * variables exist in future version of XForms
- *
  */
 
 #ifndef FL_EXTERN_H_MAKING_FORMS_ONLY
@@ -61,24 +55,28 @@ extern float fli_dpi;
 extern FL_IOPT fli_cntl;
 extern int fli_inverted_y;
 
-extern FLI_CONTEXT *fli_context;
-extern FLI_TARGET  *flx;
+extern FLI_CONTEXT * fli_context;
+extern FLI_TARGET * flx;
 extern long fli_requested_vid;
 extern int fli_no_connection;
 extern char fli_curfnt[ 127 ];
 extern FLI_WIN *fli_app_win;
 
-extern void fli_drw_tbox( int,
-						  FL_Coord,
-						  FL_Coord,
-						  FL_Coord,
-						  FL_Coord,
-						  FL_COLOR,
-						  int );
-
-
-extern void ( * fli_xyplot_return )( FL_OBJECT *,
-									 int );
+extern void fli_draw_tbox( int,
+                           FL_Coord,
+                           FL_Coord,
+                           FL_Coord,
+                           FL_Coord,
+                           FL_COLOR,
+                           int );
 
 
 #endif /* !def EXTERN.H */
+
+
+/*
+ * Local variables:
+ * tab-width: 4
+ * indent-tabs-mode: nil
+ * End:
+ */
