@@ -125,6 +125,12 @@ FL_EXPORT int fl_scrh,      /* screen dimension in pixels */
               fl_scrw;
 FL_EXPORT int fl_vmode;
 
+#define fl_visual    ( fl_state[ fl_vmode ].xvinfo->visual )
+#define fl_colormap  ( fl_state[ fl_vmode ].colormap )
+
+#define fl_get_visual( )    ( fl_state[ fl_vmode ].xvinfo->visual )
+#define fl_get_colormap( )  ( fl_state[ fl_vmode ].colormap )
+
 
 /* Current version only runs in single visual mode */
 
@@ -355,13 +361,14 @@ FL_EXPORT void fl_pieslice( int      fill,
 
 /* High level drawing routines */
 
-FL_EXPORT void fl_drw_frame( int      style,
-                             FL_Coord x,
-                             FL_Coord y,
-                             FL_Coord w,
-                             FL_Coord h,
-                             FL_COLOR c,
-                             int      bw );
+#define fl_drw_frame fl_draw_frame
+FL_EXPORT void fl_draw_frame( int      style,
+                              FL_Coord x,
+                              FL_Coord y,
+                              FL_Coord w,
+                              FL_Coord h,
+                              FL_COLOR c,
+                              int      bw );
 
 /*
  * Interfaces
