@@ -58,11 +58,11 @@ static void correct_topline( FLI_INPUT_SPEC *,
 
 static void redraw_scrollbar( FL_OBJECT * );
 
-static int make_line_visible( FL_OBJECT *,
-                              int );
+static int make_line_visible( FL_OBJECT * obj,
+                              int         ypos );
 
-static int make_char_visible( FL_OBJECT *,
-                              int );
+static int make_char_visible( FL_OBJECT * obj,
+                              int         xpos );
 
 static void copy_attributes( FL_OBJECT *,
                              FL_OBJECT * );
@@ -82,6 +82,9 @@ static int float_validator( FL_OBJECT *,
                             const char *,
                             int );
 
+static int xytopos( FLI_INPUT_SPEC * sp,
+                    int              xpos,
+                    int              ypos );
 
 enum {
     NORMAL_SELECT,
@@ -119,7 +122,7 @@ get_margin( int        btype,
 
 
 /***************************************
- * Check the size of scrollbars and input field.  No drawing is allowed
+ * Checks the size of scrollbars and input field.  No drawing is allowed
  ***************************************/
 
 static void
@@ -268,8 +271,8 @@ draw_input( FL_OBJECT * obj )
 
     if ( sp->drawtype == COMPLETE )
     {
-        fl_drw_box( obj->boxtype, sp->input->x, sp->input->y,
-                    sp->input->w, sp->input->h, col, obj->bw );
+        fl_draw_box( obj->boxtype, sp->input->x, sp->input->y,
+                     sp->input->w, sp->input->h, col, obj->bw );
         fl_draw_object_label_outside( obj );
     }
 
@@ -286,23 +289,23 @@ draw_input( FL_OBJECT * obj )
     fl_set_text_clipping( cx, cy, sp->w, sp->h );
     fl_set_clipping( cx, cy, sp->w, sp->h );
 
-    max_pixels = fli_drw_string( obj->type == FL_MULTILINE_INPUT ?
-                                 FL_ALIGN_LEFT_TOP : FL_ALIGN_LEFT,
-                                 cx - sp->xoffset,      /* Bounding box */
-                                 cy - sp->yoffset,
-                                 sp->w + sp->xoffset,
-                                 sp->h + sp->yoffset,
+    max_pixels = fli_draw_string( obj->type == FL_MULTILINE_INPUT ?
+                                  FL_ALIGN_LEFT_TOP : FL_ALIGN_LEFT,
+                                  cx - sp->xoffset,      /* Bounding box */
+                                  cy - sp->yoffset,
+                                  sp->w + sp->xoffset,
+                                  sp->h + sp->yoffset,
                                  -1,               /* Clipping is already set */
-                                 col, sp->textcol, curscol,
-                                 obj->lstyle, obj->lsize,
-                                 (    sp->cursor_visible
-                                   && obj->focus
-                                   && sp->beginrange >= sp->endrange ) ?
-                                 sp->position : -1,
-                                 sp->beginrange, sp->endrange,
+                                  col, sp->textcol, curscol,
+                                  obj->lstyle, obj->lsize,
+                                  (    sp->cursor_visible
+                                    && obj->focus
+                                    && sp->beginrange >= sp->endrange ) ?
+                                  sp->position : -1,
+                                  sp->beginrange, sp->endrange,
                                  sp->str, sp->drawtype != COMPLETE,
-                                 sp->topline,
-                                 sp->topline + sp->screenlines, 0 );
+                                  sp->topline,
+                                  sp->topline + sp->screenlines, 0 );
 
     max_pixels_line = fli_get_max_pixels_line( ) + 1;
     sp->charh = fl_get_char_height( obj->lstyle, obj->lsize, 0, 0 );
@@ -532,42 +535,15 @@ delete_piece( FL_OBJECT * obj,
 }
 
 
-/***************************************
- * Returns the width of the substring of the input field
- ***************************************/
-
-#if 1
 #define get_substring_width( o, b, e )                                       \
     fl_get_string_width( ( o )->lstyle, ( o )->lsize,                        \
                          ( ( FLI_INPUT_SPEC * ) ( o )->spec )->str + ( b ),  \
                          ( e ) - ( b ) )
 
-#else
-static int
-get_substring_width( FL_OBJECT * obj,
-                     int         startpos,
-                     int         endpos )
-{
-    FLI_INPUT_SPEC *sp = obj->spec;
-    char *str = sp->str + startpos;
-    char tmpch = sp->str[endpos];   /* Save end position */
-    int wid;                        /* The required width */
-
-    sp->str[ endpos ] = '\0';
-    wid = fl_get_string_width( obj->lstyle, obj->lsize,
-                               str, endpos - startpos );
-    sp->str[ endpos ] = tmpch;      /* Restore end position */
-
-    return wid;
-}
-
-#endif
-
 #define IsRegular( k )  (    ( k ) == '\n'                                \
                           || ( key >= 32 && key <= 255 && key != 127 ) )
 
 
-
 /***************************************
  * Editing command. Need 4 bytes. Byte1 for normal ASCII, byte2 for
  * special keysyms, such as PageUP etc. Byte 3 is used by Latin3 etc.
@@ -838,7 +814,6 @@ handle_edit( FL_OBJECT * obj,
             ret = FL_RETURN_NONE;
         else
         {
-
 #if defined USE_CLASSIC_EDITKEYS
             while (    i < slen
                     && ( sp->str[ i ] == ' ' || sp->str[ i ] == '\n' ) )
@@ -1183,6 +1158,12 @@ handle_key( FL_OBJECT    * obj,
         }
 
         handle_movement( obj, key, slen, startpos, kmask );
+
+        if ( sp->endrange != -1 )
+        {
+            make_line_visible( obj, sp->ypos );
+            make_char_visible( obj, sp->xpos );
+        }
     }
     else
         ret = handle_edit( obj, key, slen );
@@ -1441,12 +1422,12 @@ handle_input( FL_OBJECT * obj,
             if ( sp->input->type != FL_MULTILINE_INPUT )
                 fl_draw_object_label_outside( sp->input );
             else
-                fl_drw_text_beside( sp->dummy->align,
-                                    sp->input->x, sp->input->y,
-                                    sp->input->w + sp->vw,
-                                    sp->input->h + sp->hh,
-                                    sp->input->lcol, sp->input->lstyle,
-                                    sp->input->lsize, sp->dummy->label );
+                fl_draw_text_beside( sp->dummy->align,
+                                     sp->input->x, sp->input->y,
+                                     sp->input->w + sp->vw,
+                                     sp->input->h + sp->hh,
+                                     sp->input->lcol, sp->input->lstyle,
+                                     sp->input->lsize, sp->dummy->label );
             break;
 
         case FL_FOCUS:
@@ -1551,7 +1532,7 @@ handle_input( FL_OBJECT * obj,
         case FL_FREEMEM:
             fli_safe_free( ( ( FLI_INPUT_SPEC * ) obj->spec )->str );
             fli_safe_free( obj->spec );
-            break;
+            return ret;
     }
 
     if (    ret
@@ -1568,6 +1549,12 @@ handle_input( FL_OBJECT * obj,
         }
     }
 
+    /* In some places the x- and y-coordinates (column and row) of the cursor
+       aren't set consistently, so repair it here... */
+
+    if ( obj->spec )
+    fl_get_input_cursorpos( obj, &sp->xpos, &sp->ypos );
+
     return ret;
 }
 
@@ -1581,9 +1568,11 @@ vsl_cb( FL_OBJECT * obj,
         long        data  FL_UNUSED_ARG )
 {
     FLI_INPUT_SPEC *sp = obj->parent->spec;
-    double val = fl_get_scrollbar_value( obj );
-    int top = val * ( sp->lines - sp->screenlines ) + 1.01;
 
+    double val = fl_get_scrollbar_value( obj );
+    int top = FL_nint( val * ( sp->lines - sp->screenlines ) ) + 1;
+
+    sp->endrange = -1;          /* switch off selection */
     sp->drawtype = VSLIDER;
     fl_set_input_topline( sp->input, top );
 }
@@ -2142,17 +2131,34 @@ fl_set_input_selected( FL_OBJECT * obj,
 static int
 xytopos( FLI_INPUT_SPEC * sp,
          int              xpos,
-         int              ypos,
-         int              len )
+         int              ypos )
 {
-    int y;
+    int newp = 0;
     char *s = sp->str,
-         *se = s + len;
+         *se = s + strlen( s );
 
-    for ( y = 1; y < ypos && s < se; s++ )
-        if ( *s == '\n' )
-            y++;
-    return ( s - sp->str ) + xpos;
+    if ( ypos < 1 )
+        ypos = 1;
+    else if ( ypos > sp->lines )
+        ypos = sp->lines;
+
+    if ( xpos < 0 )
+        xpos = 0;
+
+    sp->ypos = 1;
+    while ( sp->ypos < ypos && ( s = strchr( s, '\n' ) ) )
+    {
+        sp->ypos++;
+        s++;
+        newp = s - sp->str;
+    }
+
+    s = sp->str + newp;
+    for ( sp->xpos = 0; sp->xpos < xpos && s < se; sp->xpos++, newp++ )
+        if (  *++s == '\n' )
+            break;
+
+    return sp->position = newp;
 }
 
 
@@ -2166,32 +2172,18 @@ fl_set_input_cursorpos( FL_OBJECT * obj,
                         int         ypos )
 {
     FLI_INPUT_SPEC *sp = obj->spec;
-    int newp,
-        len;
+    int oldp = sp->position;
 
     if ( obj->type == FL_HIDDEN_INPUT )
         return;
 
-    if ( ypos < 1 )
-        ypos = 1;
-    else if ( ypos > sp->lines )
-        ypos = sp->lines;
-
-    if ( xpos < 0 )
-        xpos = 0;
-
-    len = strlen( sp->str );
-
-    newp = xytopos( sp, xpos, ypos, len );
-
-    if ( newp > len )
-        newp = len;
-
-    if ( newp != sp->position )
+    if ( oldp != xytopos( sp, xpos, ypos ) )
     {
-        sp->position = newp;
-        make_line_visible( obj, ypos );
-        fl_redraw_object( sp->input );
+        fl_freeze_form( obj->form );
+        make_line_visible( obj, sp->ypos );
+        make_char_visible( obj, sp->xpos );
+        fl_redraw_object( obj );
+        fl_unfreeze_form( obj->form );
     }
 }
 
@@ -2205,22 +2197,24 @@ fl_get_input_cursorpos( FL_OBJECT * obj,
                         int       * y )
 {
     FLI_INPUT_SPEC *sp = obj->spec;
-    int i,
-        j;
     char *s = sp->str;
+    int cnt = 0;
 
-    for ( i = 1, j = 0; s && *s && sp->position > s - sp->str; s++ )
-    {
-        j++;
+    if ( ! obj->focus )
+        return sp->position = *x = -1;
+
+    *y = 1;
+    *x = 0;
+
+    for ( ; s && *s && cnt < sp->position; s++, cnt++ )
         if ( *s == '\n' )
         {
-            i++;
-            j = 0;
+            *y += 1;
+            *x = 0;
         }
-    }
+        else
+            *x += 1;
 
-    *x = sp->position >= 0 ? j : -1;
-    *y = i;
     return sp->position;
 }
 
@@ -2607,6 +2601,11 @@ fl_get_input_xoffset( FL_OBJECT * obj )
 
 
 /***************************************
+ * Corrects, if necessary, the value of 'top' (the topmost line to be
+ * shown in a FL_MULTILINE_INPUT object, count is starting at 1) so
+ * that the value is at least 1 and, if there are less lines below
+ * 'top' then fit into the input field, adjusts 'top' that the
+ * complete field is used (i.e. there are no empty lines at the end).
  ***************************************/
 
 static void
@@ -2615,7 +2614,7 @@ correct_topline( FLI_INPUT_SPEC * sp,
 {
     if ( sp->lines > sp->screenlines )
     {
-        if ( sp->lines + 1 - *top < sp->screenlines )
+        if ( sp->lines < *top + sp->screenlines - 1 )
             *top = sp->lines - sp->screenlines + 1;
         if ( *top < 1 )
             *top = 1;
@@ -2628,35 +2627,27 @@ correct_topline( FLI_INPUT_SPEC * sp,
 /***************************************
  ***************************************/
 
-static int
-count_lines( const char *s )
+int
+fl_get_input_numberoflines( FL_OBJECT * obj )
 {
+    FLI_INPUT_SPEC *sp = obj->spec;
     int count;
+    const char *s = sp->str;
 
     if ( ! s )
-        return 0;
+        return sp->lines = 0;
 
     for ( count = 1; *s; s++ )
         if ( *s == '\n' )
             count++;
 
-    return count;
-}
-
-
-/***************************************
- ***************************************/
-
-int
-fl_get_input_numberoflines( FL_OBJECT * obj )
-{
-    FLI_INPUT_SPEC *sp = obj->spec;
-
-    return sp->lines = count_lines( sp->str );
+    return sp->lines = count;
 }
 
 
 /***************************************
+ * Makes the requested line 'top' (starting at 1) the topmost line
+ * shown in a FL_MULTILINE_INPUT object.
  ***************************************/
 
 void
@@ -2670,18 +2661,30 @@ fl_set_input_topline( FL_OBJECT * obj,
 
     correct_topline( sp, &top );
 
-    if ( sp->topline != top )
+    if ( sp->topline == top )
+        return;
+
+    /* Make sure the cursor remains in a visible line */
+
+    if ( sp->ypos < top || sp->ypos >= top + sp->screenlines )
     {
-        sp->topline = top;
-        if ( sp->drawtype != VSLIDER )
-        {
-            check_scrollbar_size( obj );
-            redraw_scrollbar( obj );
-        }
-        sp->drawtype = COMPLETE;
-        sp->yoffset = ( sp->topline - 1 ) * sp->charh;
-        fl_redraw_object( sp->input );
+        if ( sp->ypos < top )
+            xytopos( sp, sp->xpos, top );
+        else
+            xytopos( sp, sp->xpos, top + sp->screenlines - 1 );
+        make_char_visible( obj, sp->xpos );
     }
+
+    sp->topline = top;
+    if ( sp->drawtype != VSLIDER )
+    {
+        check_scrollbar_size( obj );
+        redraw_scrollbar( obj );
+    }
+
+    sp->drawtype = COMPLETE;
+    sp->yoffset = ( sp->topline - 1 ) * sp->charh;
+    fl_redraw_object( sp->input );
 }
 
 
@@ -2691,7 +2694,7 @@ fl_set_input_topline( FL_OBJECT * obj,
 
 static int
 make_line_visible( FL_OBJECT * obj,
-                   int         n )
+                   int         ypos )
 {
     FLI_INPUT_SPEC *sp = obj->spec;
     int oldtop = sp->topline;
@@ -2699,12 +2702,12 @@ make_line_visible( FL_OBJECT * obj,
     if ( obj->type != FL_MULTILINE_INPUT )
         return 0;
 
-    if ( n < sp->topline )
-        fl_set_input_topline( obj, n );
-    else if ( n - sp->topline + 1 > sp->screenlines )
-        fl_set_input_topline( obj, n - sp->screenlines + 1 );
-    else if ( sp->lines + 1 - sp->topline < sp->screenlines )
-        fl_set_input_topline( obj, sp->lines );
+    if ( ypos < sp->topline )
+        fl_set_input_topline( obj, ypos );
+    else if ( ypos > sp->topline + sp->screenlines - 1 )
+        fl_set_input_topline( obj, ypos - sp->screenlines + 1 );
+    else if ( sp->lines < sp->screenlines )
+        fl_set_input_topline( obj, 1 );
 
     return oldtop != sp->topline;
 }
@@ -2715,20 +2718,20 @@ make_line_visible( FL_OBJECT * obj,
 
 static int
 make_char_visible( FL_OBJECT * obj,
-                   int         n )
+                   int         xpos )
 {
     FLI_INPUT_SPEC *sp = obj->spec;
-    int startpos = sp->position;
+    int start_of_line = sp->position;
     int oldxoffset = sp->xoffset;
     int tmp;
 
-    if ( n < 0 )
+    if ( xpos < 0 )
         return 0;
 
-    while ( startpos > 0 && sp->str[ startpos - 1 ] != '\n' )
-        startpos--;
+    while ( start_of_line > 0 && sp->str[ start_of_line - 1 ] != '\n' )
+        start_of_line--;
 
-    tmp = get_substring_width( obj, startpos, n + startpos );
+    tmp = get_substring_width( obj, start_of_line, start_of_line + xpos );
 
     if ( tmp < sp->xoffset )
         sp->xoffset = tmp;
@@ -2970,9 +2973,9 @@ redraw_scrollbar( FL_OBJECT * obj )
     {
         sp->dead_area = 0;
         fl_winset( FL_ObjWin( obj ) );
-        fl_drw_box( FL_FLAT_BOX, sp->dummy->x + sp->dummy->w - sp->vw,
-                    sp->dummy->y + sp->dummy->h - sp->hh, sp->vw,
-                    sp->hh, sp->hscroll->col1, 1 );
+        fl_draw_box( FL_FLAT_BOX, sp->dummy->x + sp->dummy->w - sp->vw,
+                     sp->dummy->y + sp->dummy->h - sp->hh, sp->vw,
+                     sp->hh, sp->hscroll->col1, 1 );
     }
 
     fl_unfreeze_form( obj->form );
